@@ -1,13 +1,17 @@
-
 package MooseX::Storage;
+{
+  $MooseX::Storage::VERSION = '0.39';
+}
+# git description: v0.38-TRIAL-2-g769dd9c
+
+BEGIN {
+  $MooseX::Storage::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose qw(confess);
 
 use MooseX::Storage::Meta::Attribute::DoNotSerialize;
 use String::RewritePrefix ();
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 sub import {
     my $pkg = caller();
 
@@ -119,8 +123,6 @@ MooseX::Storage - A serialization framework for Moose classes
   use Moose;
   use MooseX::Storage;
 
-  our $VERSION = '0.01';
-
   with Storage('format' => 'JSON', 'io' => 'File');
 
   has 'x' => (is => 'rw', isa => 'Int');
@@ -184,7 +186,7 @@ The first (base) level is C<pack> and C<unpack>. In this level the
 class is serialized into a Perl HASH reference, it is tagged with the
 class name and each instance attribute is stored. Very simple.
 
-This level is not optional, it is the bare minumum that
+This level is not optional, it is the bare minimum that
 MooseX::Storage provides and all other levels build on top of this.
 
 See L<MooseX::Storage::Basic> for the fundamental implementation and
@@ -200,6 +202,8 @@ specific serialization format and Perl land.
 This level is optional, if you don't want/need it, you don't have to
 have it. You can just use C<pack>/C<unpack> instead.
 
+=for stopwords io
+
 =item B<io>
 
 The third (io) level is C<load> and C<store>. In this level we are reading
@@ -224,7 +228,7 @@ The following traits are currently bundled with C<MooseX::Storage>:
 
 =item OnlyWhenBuilt
 
-Only attributes that have been built (ie, where the predicate returns
+Only attributes that have been built (i.e., where the predicate returns
 'true') will be serialized. This avoids any potentially expensive computations.
 
 See L<MooseX::Storage::Traits::OnlyWhenBuilt> for details.
@@ -244,9 +248,11 @@ MooseX::Storage enabled objects are supported.
 
 With Array and Hash references the first level down is inspected and
 any objects found are serialized/deserialized for you. We do not do
-this recusively by default, however this feature may become an
+this recursively by default, however this feature may become an
 option eventually.
 
+=for stopwords subtypes
+
 The specific serialize/deserialize routine is determined by the
 Moose type constraint a specific attribute has. In most cases subtypes
 of the supported types are handled correctly, and there is a facility
@@ -296,6 +302,8 @@ that is not under the default namespace prefix, start with an equal sign:
 
   Storage(format => '=My::Private::JSONFormat');
 
+=for stopwords parameterized
+
 To use a parameterized role (for which, see L<MooseX::Role::Parameterized>) you
 can pass an arrayref of the role name (in short or long form, as above) and its
 parameters:
@@ -320,6 +328,8 @@ parameters:
 
 =back
 
+=for stopwords TODO
+
 =head1 TODO
 
 This module needs docs and probably a Cookbook of some kind as well.
@@ -353,3 +363,5 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =cut
+
+
