@@ -1,4 +1,10 @@
 package MooseX::Storage::Base::WithChecksum;
+{
+  $MooseX::Storage::Base::WithChecksum::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::Base::WithChecksum::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose::Role;
 
 with 'MooseX::Storage::Basic';
@@ -6,9 +12,6 @@ with 'MooseX::Storage::Basic';
 use Digest       ();
 use Data::Dumper ();
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 our $DIGEST_MARKER = '__DIGEST__';
 
 around pack => sub {
