@@ -1,9 +1,12 @@
 package MooseX::Storage::Deferred;
+{
+  $MooseX::Storage::Deferred::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::Deferred::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose::Role;
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'MooseX::Storage::Basic';
 
 sub __get_method {
@@ -67,6 +70,8 @@ __END__
 
 =head1 NAME
 
+=for stopwords undecisive
+
 MooseX::Storage::Deferred - A role for undecisive programmers
 
 =head1 SYNOPSIS
@@ -75,8 +80,6 @@ MooseX::Storage::Deferred - A role for undecisive programmers
   use Moose;
   use MooseX::Storage;
 
-  our $VERSION = '0.01';
-
   with 'MooseX::Storage::Deferred';
 
   has 'x' => (is => 'rw', isa => 'Int');
@@ -117,6 +120,8 @@ SYNOPSIS for more info)
 
 =item I<JSON>
 
+=for stopwords JSONpm
+
 =item I<JSONpm>
 
 =item I<YAML>
