@@ -1,22 +1,24 @@
 package MooseX::Storage::Engine::IO::AtomicFile;
+{
+  $MooseX::Storage::Engine::IO::AtomicFile::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::Engine::IO::AtomicFile::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose;
 
-use utf8 ();
 use IO::AtomicFile;
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 extends 'MooseX::Storage::Engine::IO::File';
 
 sub store {
-	my ($self, $data) = @_;
-	my $fh = IO::AtomicFile->new($self->file, 'w')
-	    || confess "Unable to open file (" . $self->file . ") for storing : $!";
-	$fh->binmode(':utf8') if utf8::is_utf8($data);	    
-	print $fh $data;
-	$fh->close() 
-	    || confess "Could not write atomic file (" . $self->file . ") because: $!";
+    my ($self, $data) = @_;
+    my $fh = IO::AtomicFile->new($self->file, 'w')
+        || confess "Unable to open file (" . $self->file . ") for storing : $!";
+    $fh->binmode(':utf8') if utf8::is_utf8($data);
+    print $fh $data;
+    $fh->close()
+        || confess "Could not write atomic file (" . $self->file . ") because: $!";
 }
 
 1;
@@ -55,7 +57,7 @@ This provides the actual means to store data to a file atomically.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
