@@ -1,4 +1,10 @@
 package MooseX::Storage::Format::YAML;
+{
+  $MooseX::Storage::Format::YAML::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::Format::YAML::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose::Role;
 
 # When I add YAML::LibYAML
@@ -7,9 +13,6 @@ use Moose::Role;
 
 use YAML::Any qw(Load Dump);
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 requires 'pack';
 requires 'unpack';
 
