@@ -1,11 +1,14 @@
 package MooseX::Storage::IO::AtomicFile;
+{
+  $MooseX::Storage::IO::AtomicFile::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::IO::AtomicFile::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose::Role;
 
 use MooseX::Storage::Engine::IO::AtomicFile;
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 with 'MooseX::Storage::IO::File';
 
 sub store {
