@@ -1,17 +1,23 @@
 package MooseX::Storage::Meta::Attribute::DoNotSerialize;
+{
+  $MooseX::Storage::Meta::Attribute::DoNotSerialize::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::Meta::Attribute::DoNotSerialize::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose;
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 extends 'Moose::Meta::Attribute';
    with 'MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize';
 
 # register this alias ...
 package Moose::Meta::Attribute::Custom::DoNotSerialize;
-
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
+{
+  $Moose::Meta::Attribute::Custom::DoNotSerialize::VERSION = '0.39';
+}
+BEGIN {
+  $Moose::Meta::Attribute::Custom::DoNotSerialize::AUTHORITY = 'cpan:STEVAN';
+}
 
 sub register_implementation { 'MooseX::Storage::Meta::Attribute::DoNotSerialize' }
 
@@ -30,24 +36,26 @@ MooseX::Storage::Meta::Attribute::DoNotSerialize - A custom meta-attribute to by
   package Point;
   use Moose;
   use MooseX::Storage;
-  
+
   with Storage('format' => 'JSON', 'io' => 'File');
-  
+
   has 'x' => (is => 'rw', isa => 'Int');
   has 'y' => (is => 'rw', isa => 'Int');
-  
+
   has 'foo' => (
       metaclass => 'DoNotSerialize',
       is        => 'rw',
       isa       => 'CodeRef',
   );
-  
+
   1;
 
 =head1 DESCRIPTION
 
-Sometimes you don't want a particular attribute to be part of the 
-serialization, in this case, you want to make sure that attribute 
+=for stopwords culted
+
+Sometimes you don't want a particular attribute to be part of the
+serialization, in this case, you want to make sure that attribute
 uses this custom meta-attribute. See the SYNOPSIS for a nice example
 that can be easily cargo-culted.
 
@@ -63,7 +71,7 @@ that can be easily cargo-culted.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
