@@ -1,15 +1,21 @@
 
 package MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize;
+{
+  $MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose::Role;
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 # register this alias ...
 package Moose::Meta::Attribute::Custom::Trait::DoNotSerialize;
-
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
+{
+  $Moose::Meta::Attribute::Custom::Trait::DoNotSerialize::VERSION = '0.39';
+}
+BEGIN {
+  $Moose::Meta::Attribute::Custom::Trait::DoNotSerialize::AUTHORITY = 'cpan:STEVAN';
+}
 
 sub register_implementation { 'MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize' }
 
@@ -28,25 +34,27 @@ MooseX::Storage::Meta::Attribute::Trait::DoNotSerialize - A custom meta-attribut
   package Point;
   use Moose;
   use MooseX::Storage;
-  
+
   with Storage('format' => 'JSON', 'io' => 'File');
-  
+
   has 'x' => (is => 'rw', isa => 'Int');
   has 'y' => (is => 'rw', isa => 'Int');
-  
+
   has 'foo' => (
       traits => [ 'DoNotSerialize' ],
       is     => 'rw',
       isa    => 'CodeRef',
   );
-  
+
   1;
 
 =head1 DESCRIPTION
 
-Sometimes you don't want a particular attribute to be part of the 
-serialization, in this case, you want to make sure that attribute 
-uses this custom meta-attribute-trait. See the SYNOPSIS for a nice 
+=for stopwords culted
+
+Sometimes you don't want a particular attribute to be part of the
+serialization, in this case, you want to make sure that attribute
+uses this custom meta-attribute-trait. See the SYNOPSIS for a nice
 example that can be easily cargo-culted.
 
 =head1 METHODS
@@ -61,7 +69,7 @@ example that can be easily cargo-culted.
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no 
+All complex software has bugs lurking in it, and this module is no
 exception. If you find a bug please either email me, or add the bug
 to cpan-RT.
 
