@@ -1,9 +1,12 @@
 package MooseX::Storage::Traits::OnlyWhenBuilt;
+{
+  $MooseX::Storage::Traits::OnlyWhenBuilt::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::Traits::OnlyWhenBuilt::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose::Role;
 
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
-
 requires 'pack';
 requires 'unpack';
 
@@ -63,9 +66,11 @@ MooseX::Storage::Traits::OnlyWhenBuilt - A custom trait to bypass serialization
 Sometimes you don't want a particular attribute to be part of the
 serialization if it has not been built yet. If you invoke C<Storage()>
 as outlined in the C<Synopsis>, only attributes that have been built
-(ie, where the predicate returns 'true') will be serialized.
+(i.e., where the predicate returns 'true') will be serialized.
 This avoids any potentially expensive computations.
 
+=for stopwords culted
+
 See the SYNOPSIS for a nice example that can be easily cargo-culted.
 
 =head1 METHODS
