@@ -1,11 +1,13 @@
 package MooseX::Storage::Util;
+{
+  $MooseX::Storage::Util::VERSION = '0.39';
+}
+BEGIN {
+  $MooseX::Storage::Util::AUTHORITY = 'cpan:STEVAN';
+}
 use Moose qw(confess blessed);
 
 use MooseX::Storage::Engine ();
-use utf8 ();
-
-our $VERSION   = '0.35';
-our $AUTHORITY = 'cpan:STEVAN';
 
 sub peek {
     my ($class, $data, %options) = @_;
@@ -30,7 +32,7 @@ sub peek {
 }
 
 sub _inflate_json {
-    my ($class, $json) = @_;
+    my ($self, $json) = @_;
 
     eval { require JSON::Any; JSON::Any->import };
     confess "Could not load JSON module because : $@" if $@;
@@ -46,7 +48,7 @@ sub _inflate_json {
 }
 
 sub _inflate_yaml {
-    my ($class, $yaml) = @_;
+    my ($self, $yaml) = @_;
 
     require Best;
     eval { Best->import([[ qw[YAML::Syck YAML] ]]) };
@@ -74,7 +76,7 @@ __END__
 
 =head1 NAME
 
-MooseX::Storage::Util - A MooseX::Storage swiss-army chainsaw
+MooseX::Storage::Util - A MooseX::Storage Swiss Army chainsaw
 
 =head1 DESCRIPTION
 
@@ -127,6 +129,8 @@ found in the key for you.
 
 =back
 
+=for stopwords TODO
+
 =head1 TODO
 
 Add more stuff to this module :)
